MetaSEO class abstract
Make it as interface to implement later on only Web platform
- Implementers
Constructors
- MetaSEO()
-
Check the platform if is web so get the correct code
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
seoAuthor(
String author) → void -
Definition of
authormeta tag attribute https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML#adding_an_author_and_description Add web mata data ofauthorattribute -
seoCharset(
String charset) → void -
Definition of
charsetmeta tag attribute https://developer.mozilla.org/en-US/docs/Web/HTML/Element/meta#attr-charset Add web mata data ofcharsetattribute -
seoDescription(
String description) → void -
Definition of
descriptionmeta tag attribute https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML#adding_an_author_and_description Add web mata data ofdescriptionattribute -
seoHttpEquiv(
String httpEquiv) → void -
Definition of
http-equivmeta tag attribute https://developer.mozilla.org/en-US/docs/Web/HTML/Element/meta#attr-http-equiv Add web mata data ofhttpEquivattribute -
seoKeywords(
String keywords) → void -
Definition of
keywordsmeta tag attribute Separate list of keyword strings by commas Add web mata data ofkeywordsattribute -
seoMetaConfig(
) → void -
Add web seo mata config method which remove any javascript
code with the same id
metaSEOScriptsand replace if exists with needed one before the end of the body of the html web file automatically. This method should be run before any meta seo method to run the package correctly -
seoMetaKeyValue(
String metaKey, String metaValue) → void -
Definition of
metaKeymeta tag attribute If you do not found meta key you want just use metaKey Definition ofmetaValuemeta tag attribute The value is used for other key-value meta not listed in attributes by metaValue Add web mata data of other meta key with value -
seoMetaNameContent(
String metaName, String metaNameContent) → void -
Definition of
metaNamemeta tag attribute If you do not found meta name you want just use metaName Definition ofmetaNameContentmeta tag attribute The value is used for other named meta not listed in attributes by metaNameContent Add web mata data of other meta named with content -
seoMetaPropertyContent(
String metaProperty, String metaPropertyContent) → void -
Definition of
metaPropertymeta tag attribute If you do not found meta property you want just use metaProperty Definition ofmetaPropertyContentmeta tag attribute The value is used for other property meta not listed in attributes by metaPropertyContent Add web mata data of other meta property with content -
seoOGDescription(
String ogDescription) → void -
Definition of
og:descriptionmeta tag attribute https://ogp.me https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML#other_types_of_metadata Add web mata data ofogDescriptionattribute -
seoOGImage(
String ogImage) → void -
Definition of
og:imagemeta tag attribute https://ogp.me https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML#other_types_of_metadata Add web mata data ofogImageattribute -
seoOGTitle(
String ogTitle) → void -
Definition of
og:titlemeta tag attribute https://ogp.me https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML#other_types_of_metadata Add web mata data ofogTitleattribute -
seoRobots(
String robots) → void -
Definition of
robotsmeta tag attribute https://developers.google.com/search/docs/crawling-indexing/robots-meta-tag Add web mata data ofrobotsattribute -
seoTwitterDescription(
String twitterDescription) → void -
Definition of
twitter:descriptionmeta tag attribute https://developer.twitter.com/en/docs/twitter-for-websites/cards/overview/markup Add web mata data oftwitterDescriptionattribute -
seoTwitterImage(
String twitterImage) → void -
Definition of
twitter:imagemeta tag attribute https://developer.twitter.com/en/docs/twitter-for-websites/cards/overview/markup Add web mata data oftwitterImageattribute -
seoTwitterTitle(
String twitterTitle) → void -
Definition of
twitter:titlemeta tag attribute https://developer.twitter.com/en/docs/twitter-for-websites/cards/overview/markup Add web mata data oftwitterTitleattribute -
seoViewport(
String viewport) → void -
Definition of
viewportmeta tag attribute Separate list of viewport strings by commas https://developer.mozilla.org/en-US/docs/Web/HTML/Viewport_meta_tag Add web mata data ofviewportattribute -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited