keyValue abstract method
Definition of key meta tag attribute
If you do not found meta key you want just use metaKey
Definition of value meta tag attribute
The value is used for other key-value meta not listed in attributes by metaValue
Add web mata data of other meta key with value
Implementation
keyValue(
{
/// Definition of [key] meta tag attribute
required String key,
/// Definition of [value] meta tag attribute
required String value});