WebMetaSEO class
Code starts here
- Implemented types
Constructors
- WebMetaSEO()
- Definition of WebMetaSEO instance
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
seoAuthor(
String author) → void -
Definition of
authormeta tag attribute https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML#adding_an_author_and_description Add web mata data ofauthorattribute Example: String? author = 'Eng Mouaz M AlShahmeh'; Implement the interfaceoverride -
seoCharset(
String charset) → void -
Definition of
charsetmeta tag attribute https://developer.mozilla.org/en-US/docs/Web/HTML/Element/meta#attr-charset Add web mata data ofcharsetattribute Example: String? charset = 'UTF-8'; Implement the interfaceoverride -
seoDescription(
String description) → void -
Definition of
descriptionmeta tag attribute https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML#adding_an_author_and_description Add web mata data ofdescriptionattribute Example: String? description = 'Simple SEO description mata data'; Implement the interfaceoverride -
seoHttpEquiv(
String httpEquiv) → void -
Definition of
http-equivmeta tag attribute https://developer.mozilla.org/en-US/docs/Web/HTML/Element/meta#attr-http-equiv Add web mata data ofhttpEquivattribute Example: String? httpEquiv = 'X-UA-Compatible'; Implement the interfaceoverride -
seoKeywords(
String keywords) → void -
Definition of
keywordsmeta tag attribute Separate list of keyword strings by commas Add web mata data ofkeywordsattribute Example: String? keywords = 'Flutter, Dart, Simple SEO'; Implement the interfaceoverride -
seoMetaKeyValue(
String metaKey, String metaValue) → void -
Definition of
metaKeymeta tag attribute If you do not found meta key you want just use metaKey Definition ofmetaValuemeta tag attribute The value is used for other key-value meta not listed in attributes by metaValue Add web mata data of other meta key with value Implement the interfaceoverride -
seoMetaNameContent(
String metaName, String metaNameContent) → void -
Definition of
metaNamemeta tag attribute If you do not found meta name you want just use metaName Definition ofmetaNameContentmeta tag attribute The value is used for other named meta not listed in attributes by metaNameContent Add web mata data of other meta named with content Implement the interfaceoverride -
seoMetaPropertyContent(
String metaProperty, String metaPropertyContent) → void -
Definition of
metaPropertymeta tag attribute If you do not found meta property you want just use metaProperty Definition ofmetaPropertyContentmeta tag attribute The value is used for other property meta not listed in attributes by metaPropertyContent Add web mata data of other meta property with content Implement the interfaceoverride -
seoOGDescription(
String ogDescription) → void -
Definition of
og:descriptionmeta tag attribute https://ogp.me https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML#other_types_of_metadata Add web mata data ofogDescriptionattribute Implement the interfaceoverride -
seoOGImage(
String ogImage) → void -
Definition of
og:imagemeta tag attribute https://ogp.me https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML#other_types_of_metadata Add web mata data ofogImageattribute Implement the interfaceoverride -
seoOGTitle(
String ogTitle) → void -
Definition of
og:titlemeta tag attribute https://ogp.me https://developer.mozilla.org/en-US/docs/Learn/HTML/Introduction_to_HTML/The_head_metadata_in_HTML#other_types_of_metadata Add web mata data ofogTitleattribute Implement the interfaceoverride -
seoRobots(
String robots) → void -
Definition of
robotsmeta tag attribute https://developers.google.com/search/docs/crawling-indexing/robots-meta-tag Add web mata data ofrobotsattribute Example: String? robots = 'noindex, nofollow'; Implement the interfaceoverride -
seoTwitterDescription(
String twitterDescription) → void -
Definition of
twitter:descriptionmeta tag attribute https://developer.twitter.com/en/docs/twitter-for-websites/cards/overview/markup Add web mata data oftwitterDescriptionattribute Implement the interfaceoverride -
seoTwitterImage(
String twitterImage) → void -
Definition of
twitter:imagemeta tag attribute https://developer.twitter.com/en/docs/twitter-for-websites/cards/overview/markup Add web mata data oftwitterImageattribute Implement the interfaceoverride -
seoTwitterTitle(
String twitterTitle) → void -
Definition of
twitter:titlemeta tag attribute https://developer.twitter.com/en/docs/twitter-for-websites/cards/overview/markup Add web mata data oftwitterTitleattribute Implement the interfaceoverride -
seoViewport(
String viewport) → void -
Definition of
viewportmeta tag attribute Separate list of viewport strings by commas https://developer.mozilla.org/en-US/docs/Web/HTML/Viewport_meta_tag Add web mata data ofviewportattribute Example: String? viewport = 'width=device-width, initial-scale=1'; Implement the interfaceoverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited